{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "label": "BAM files",
                    "doc": "Array of input BAM files",
                    "id": "#heatmap-prepare.cwl/bam_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "label": "Fragment sizes",
                    "doc": "Array of fragment sizes",
                    "id": "#heatmap-prepare.cwl/fragment_size"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "label": "Total reads numbers",
                    "doc": "Array of total reads number for downstream normalization",
                    "id": "#heatmap-prepare.cwl/total_reads"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "label": "Tag directories",
                    "doc": "Array of tag directories",
                    "outputSource": "#heatmap-prepare.cwl/make_tag_directory/output_tag_folder",
                    "id": "#heatmap-prepare.cwl/tag_folder"
                }
            ],
            "steps": [
                {
                    "run": "#homer-make-tag-directory.cwl",
                    "in": [
                        {
                            "source": "#heatmap-prepare.cwl/bam_file",
                            "id": "#heatmap-prepare.cwl/make_tag_directory/bam_file"
                        },
                        {
                            "source": "#heatmap-prepare.cwl/fragment_size",
                            "id": "#heatmap-prepare.cwl/make_tag_directory/fragment_size"
                        },
                        {
                            "source": "#heatmap-prepare.cwl/total_reads",
                            "id": "#heatmap-prepare.cwl/make_tag_directory/total_reads"
                        }
                    ],
                    "scatter": [
                        "#heatmap-prepare.cwl/make_tag_directory/bam_file",
                        "#heatmap-prepare.cwl/make_tag_directory/fragment_size",
                        "#heatmap-prepare.cwl/make_tag_directory/total_reads"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#heatmap-prepare.cwl/make_tag_directory/output_tag_folder"
                    ],
                    "id": "#heatmap-prepare.cwl/make_tag_directory"
                }
            ],
            "doc": "Workflow runs homer-make-tag-directory.cwl tool using scatter for the following inputs\n  - bam_file\n  - fragment_size\n  - total_reads\n\n`dotproduct` is used as a `scatterMethod`, so one element will be taken from each array to construct each job:\n  1) bam_file[0] fragment_size[0] total_reads[0]\n  2) bam_file[1] fragment_size[1] total_reads[1]\n     ...\n  N) bam_file[N] fragment_size[N] total_reads[N]\n\n`bam_file`, `fragment_size` and `total_reads` arrays should have the identical order.\n",
            "id": "#heatmap-prepare.cwl",
            "http://schema.org/name": "heatmap-prepare",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/workflows/heatmap-prepare.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Runs homer-make-tag-directory.cwl with the scatter using dot product of the inputs bam_file, fragment_size and total_reads.\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/homer:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-ghist"
                    },
                    "doc": "Generate heatmap. Instead of averaging all of the data\nfrom each peak, keep data from each peak separate\n",
                    "id": "#homer-annotate-peaks-hist.cwl/export_heatmap"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-hist"
                    },
                    "doc": "Bin size, bp. If hist_width is \"given\" or skipped, this\nparameter will set the number of bins to divide each region into\n",
                    "id": "#homer-annotate-peaks-hist.cwl/hist_bin_size"
                },
                {
                    "type": [
                        "int",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-size"
                    },
                    "doc": "Possible values:\n  \"#\" - performs analysis on the \"#\" bp surrounding the peak centers\n  \"#,#\" - performs analysis from \"#\" to \"#\" relative to peak center\n  \"given\" - set size to actual coordinates in peak/BED file\n",
                    "id": "#homer-annotate-peaks-hist.cwl/hist_width"
                },
                {
                    "type": "string",
                    "doc": "Output histogram's filename",
                    "id": "#homer-annotate-peaks-hist.cwl/histogram_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-fpkm"
                    },
                    "doc": "Normalize read counts to million reads or fragments per kilobase mapped\n",
                    "id": "#homer-annotate-peaks-hist.cwl/norm_fpkm"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "-normLength"
                    },
                    "doc": "Fragment length to normlize to for experiments with different lens. Default: 100bp\n",
                    "id": "#homer-annotate-peaks-hist.cwl/norm_fragment_size"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-raw"
                    },
                    "doc": "Do not adjust the tag counts based on total tags sequenced.\nBy default all tag counts will be normalized to norm_tag_count\n",
                    "id": "#homer-annotate-peaks-hist.cwl/norm_raw"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "-norm"
                    },
                    "doc": "Normalize tags to this tag count, default=1e7, 0=average tag count in all directories\n",
                    "id": "#homer-annotate-peaks-hist.cwl/norm_tag_count"
                },
                {
                    "type": "File",
                    "doc": "Homer generated peak file or BED",
                    "id": "#homer-annotate-peaks-hist.cwl/peak_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "-strand"
                    },
                    "doc": "Count tags on specific strands relative to peak. Default: both\nPossible values: +|-\n",
                    "id": "#homer-annotate-peaks-hist.cwl/strand"
                },
                {
                    "type": [
                        "Directory",
                        {
                            "type": "array",
                            "items": "Directory"
                        }
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-d"
                    },
                    "doc": "Tag folders from homer-make-tag-directory tool",
                    "id": "#homer-annotate-peaks-hist.cwl/tag_folders"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 16,
                        "prefix": "-cpu"
                    },
                    "doc": "Set the number of threads. Default: 1\n",
                    "id": "#homer-annotate-peaks-hist.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "Output histogram file",
                    "id": "#homer-annotate-peaks-hist.cwl/histogram_file",
                    "outputBinding": {
                        "glob": "${return inputs.histogram_filename;}"
                    }
                }
            ],
            "stdout": "${return inputs.histogram_filename;}",
            "baseCommand": [
                "annotatePeaks.pl"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.peak_file)",
                    "position": 5
                },
                {
                    "valueFrom": "$(\"none\")",
                    "position": 6
                }
            ],
            "doc": "Tool is used to produce histogram or heatmaps only. Rest of the functionality is not implemented intentionally.\nIf TSS analysis needed, input peak_file should be centered on TSS, where the 'center' of the peak in the actual TSS.\nFor example:\n  1\tchr4\t978796\t978796\t-\n  2\tchr4\t1052109\t1052109\t+\n  3\tchr4\t1105422\t1105422\t-\n\nSkipped arguments:\n\n  Related to peaks annotation:\n    -organism\n    -gtf\n    -gff\n    -gff3\n    -gid\n    -ann\n    -mask\n    -p\n    -pdist\n    -pcount\n    -vcf\n    -editDistance\n    -individuals\n    -gene\n    -go\n    -genomeOntology\n    -ratio\n    -rlog\n    -vst\n    -CpG\n    -nfr\n    -nfrSize\n    -gwasCatalog\n    -map\n    -noann\n\n  Related to tss/tts/rna modes:\n    tss\n    tts\n    rna\n    -list\n    -cTSS\n\n  Related to motifs:\n    -m\n    -mscore\n    -nmotifs\n    -mdist\n    -mfasta\n    -fm\n    -rmrevopp\n    -matrix\n    -mbed\n    -mlogic\n    -norevopp\n\n  Related to peak centering:\n    -center\n    -mirror\n    -multi\n\n  Related to genome comparisons\n    -cmpGenome\n    -cmpLiftover\n\n  Currently not needed functionality:\n    -bedGraph\n    -wig\n    -nuc\n    -di\n    -histNorm\n    -rm\n    -log\n    -sqrt\n    -len\n    -pc\n    -noblanks\n    -homer1\n    -homer2\n",
            "id": "#homer-annotate-peaks-hist.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#homer-metadata.yaml",
                "http://schema.org/name": "Homer",
                "http://schema.org/about": "HOMER (Hypergeometric Optimization of Motif EnRichment)"
            },
            "http://schema.org/name": "homer-annotate-peaks-hist",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/homer-annotate-peaks-hist.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: annotatePeaks.pl <peak file | tss> <genome version>  [additional options...]\n\n    Available Genomes (required argument): (name,org,directory,default promoter set)\n            -- or --\n        Custom: provide the path to genome FASTA files (directory or single file)\n        If no genome is available, specify 'none'.\n        If using FASTA file or none, may want to specify '-organism <...>'\n\n    User defined annotation files (default is UCSC refGene annotation):\n        annotatePeaks.pl accepts GTF (gene transfer formatted) files to annotate positions relative\n        to custom annotations, such as those from de novo transcript discovery or Gencode.\n        -gtf <gtf format file> (Use -gff and -gff3 if appropriate, but GTF is better)\n        -gid (by default the GTF file is processed by transcript_id, use this option for gene_id)\n        -ann <custom homer annotation file> (created by assignGenomeAnnotation, see website)\n\n    Peak vs. tss/tts/rna mode (works with custom GTF file):\n        If the first argument is \"tss\" (i.e. annotatePeaks.pl tss hg18 ...) then a TSS centric\n        analysis will be carried out.  Tag counts and motifs will be found relative to the TSS.\n        (no position file needed) [\"tts\" now works too - e.g. 3' end of gene]\n        [\"rna\" specifies gene bodies, will automaticall set \"-size given\"]\n        NOTE: The default TSS peak size is 4000 bp, i.e. +/- 2kb (change with -size option)\n        -list <gene id list> (subset of genes to perform analysis [unigene, gene id, accession,\n             probe, etc.], default = all promoters)\n        -cTSS <promoter position file i.e. peak file> (should be centered on TSS)\n\n    Primary Annotation Options:\n        -mask (Masked repeats, can also add 'r' to end of genome name)\n        -m <motif file 1> [motif file 2] ... (list of motifs to find in peaks)\n            -mscore (reports the highest log-odds score within the peak)\n            -nmotifs (reports the number of motifs per peak)\n            -mdist (reports distance to closest motif)\n            -mfasta <filename> (reports sites in a fasta file - for building new motifs)\n            -fm <motif file 1> [motif file 2] (list of motifs to filter from above)\n            -rmrevopp <#> (only count sites found within <#> on both strands once, i.e. palindromic)\n            -matrix <prefix> (outputs a motif co-occurrence files:\n                prefix.count.matrix.txt - number of peaks with motif co-occurrence\n                prefix.ratio.matrix.txt - ratio of observed vs. expected  co-occurrence\n                prefix.logPvalue.matrix.txt - co-occurrence enrichment\n                prefix.stats.txt - table of pair-wise motif co-occurrence statistics\n                additional options:\n                -matrixMinDist <#> (minimum distance between motif pairs - to avoid overlap, default: 4)\n                -matrixMaxDist <#> (maximum distance between motif pairs)\n            -mbed <filename> (Output motif positions to a BED file to load at UCSC (or -mpeak))\n            -mlogic <filename> (will output stats on common motif orientations)\n        -d <tag directory 1> [tag directory 2] ... (list of experiment directories to show\n            tag counts for) NOTE: -dfile <file> where file is a list of directories in first column\n        -bedGraph <bedGraph file 1> [bedGraph file 2] ... (read coverage counts from bedGraph files)\n        -wig <wiggle file 1> [wiggle file 2] ... (read coverage counts from wiggle files)\n        -p <peak file> [peak file 2] ... (to find nearest peaks)\n            -pdist to report only distance (-pdist2 gives directional distance)\n            -pcount to report number of peaks within region\n        -vcf <VCF file> (annotate peaks with genetic variation infomation, one col per individual)\n            -editDistance (Computes the # bp changes relative to reference)\n            -individuals <name1> [name2] ... (restrict analysis to these individuals)\n            -editDistance (Computes the # bp changes relative to reference)\n            -individuals <name1> [name2] ... (restrict analysis to these individuals)\n        -gene <data file> ... (Adds additional data to result based on the closest gene.\n            This is useful for adding gene expression data.  The file must have a header,\n            and the first column must be a GeneID, Accession number, etc.  If the peak\n            cannot be mapped to data in the file then the entry will be left empty.\n        -go <output directory> (perform GO analysis using genes near peaks)\n        -genomeOntology <output directory> (perform genomeOntology analysis on peaks)\n            -gsize <#> (Genome size for genomeOntology analysis, default: 2e9)\n\n    Annotation vs. Histogram mode:\n        -hist <bin size in bp> (i.e 1, 2, 5, 10, 20, 50, 100 etc.)\n        The -hist option can be used to generate histograms of position dependent features relative\n        to the center of peaks.  This is primarily meant to be used with -d and -m options to map\n        distribution of motifs and ChIP-Seq tags.  For ChIP-Seq peaks for a Transcription factor\n        you might want to use the -center option (below) to center peaks on the known motif\n        ** If using \"-size given\", histogram will be scaled to each region (i.e. 0-100%), with\n        the -hist parameter being the number of bins to divide each region into.\n            Histogram Mode specific Options:\n            -nuc (calculated mononucleotide frequencies at each position,\n                Will report by default if extracting sequence for other purposes like motifs)\n            -di (calculated dinucleotide frequencies at each position)\n            -histNorm <#> (normalize the total tag count for each region to 1, where <#> is the\n                minimum tag total per region - use to avoid tag spikes from low coverage\n            -ghist (outputs profiles for each gene, for peak shape clustering)\n            -rm <#> (remove occurrences of same motif that occur within # bp)\n\n    Peak Centering: (other options are ignored)\n        -center <motif file> (This will re-center peaks on the specified motif, or remove peak\n            if there is no motif in the peak.  ONLY recentering will be performed, and all other\n            options will be ignored.  This will output a new peak file that can then be reanalyzed\n            to reveal fine-grain structure in peaks (It is advised to use -size < 200) with this\n            to keep peaks from moving too far (-mirror flips the position)\n        -multi (returns genomic positions of all sites instead of just the closest to center)\n\n    Genome comparisons (need genome & liftOver)\n        -cmpGenome <genome1> [genome2] (Genomes to compare for sequence/motifs)\n        -cmpLiftover <liftover1> [genome2] (Genomes to compare for sequence/motifs)\n\n    Normalization options:\n        -fpkm (normalize read counts to million reads or fragments per kilobase mapped)\n        -raw (do not adjust the tag counts based on total tags sequenced, -noadj works too)\n        -norm <#> (normalize tags to this tag count, default=1e7, 0=average tag count in all directories)\n        -normLength <#> (Fragment length to normlize to for experiments with different lens, def: 100)\n        -log (output tag counts as log2(x+1+rand) values - for scatter plots)\n        -sqrt (output tag counts as sqrt(x+rand) values - for scatter plots)\n        -ratio (process tag values as ratios - i.e. chip-seq, or mCpG/CpG)\n\n    Advanced normalization options: (-rlog and -vst require R and DESeq2 to be installed)\n        -rlog (quantile/variance normalization on reported genes using DESeq2 rlog funcition, needs R)\n        -vst (quantile/variance normalization on reported genes using DESeq2 vst function, needs R)\n\n    Advanced Options:\n        -len <#> / -fragLength <#> (Fragment length, default=auto, might want to set to 1 for 5'RNA)\n        -size <#> (Peak size[from center of peak], default=inferred from peak file)\n            -size #,# (i.e. -size -10,50 count tags from -10 bp to +50 bp from center)\n            -size \"given\" (count tags etc. using the actual regions - for variable length regions)\n        -strand <+|-|both> (Count tags on specific strands relative to peak, default: both)\n        -pc <#> (maximum number of tags to count per bp, default=0 [no maximum], -tbp <#> works too)\n        -CpG (Calculate CpG/GC content)\n        -nfr (report nuclesome free region scores instead of tag counts, also -nfrSize <#>)\n        -norevopp (do not search for motifs on the opposite strand [works with -center too])\n        -gwasCatalog <gwasCatalog file from UCSC> (list overlapping GWAS risk SNPs)\n        -pdist (only report distance to nearest peak using -p, not peak name)\n        -map <mapping file> (mapping between peak IDs and promoter IDs, overrides closest assignment)\n        -noann, -nogene (skip genome annotation step, skip TSS annotation)\n        -homer1/-homer2 (by default, the new version of homer [-homer2] is used for finding motifs)\n        -cpu <#> (Number of processors to use when possible - only some parts utilize multiple cores)\n        -noblanks (remove peaks/rows with missing data)\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  return [\n    {\"class\": \"Directory\",\n     \"basename\": \"default\",\n     \"listing\": [inputs.bam_file],\n     \"writable\": true}\n  ]\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/homer:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Alignment file, BAM",
                    "id": "#homer-make-tag-directory.cwl/bam_file"
                },
                {
                    "type": [
                        "null",
                        "int",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-fragLength"
                    },
                    "doc": "Set fragment size.\nBy default is estimated as if it was single end ChIP-Seq experiment.\nPossible values:\n  \"#\" - int value to be used as fragment size\n  \"given\" - use read lengths\n  \"pe\" - calculate from paired end read coordinates\n",
                    "id": "#homer-make-tag-directory.cwl/fragment_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-maxlen"
                    },
                    "doc": "Discard reads bigger then\n",
                    "id": "#homer-make-tag-directory.cwl/max_length"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-minlen"
                    },
                    "doc": "Discard reads smaller then\n",
                    "id": "#homer-make-tag-directory.cwl/min_length"
                },
                {
                    "type": [
                        "null",
                        "int",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-totalReads"
                    },
                    "doc": "Set total reads number for downstream normalization.\nDefault: autocalculated, equal to uniquely mapped reads number\nPossible values:\n  \"#\" - int value to be used as total reads number\n  \"all\" - autocalculated, equal to uniquely + multi mapped reads number\n",
                    "id": "#homer-make-tag-directory.cwl/total_reads"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.bam_file.basename.split('.')[0])"
                    },
                    "doc": "Tag directory",
                    "id": "#homer-make-tag-directory.cwl/output_tag_folder"
                }
            ],
            "baseCommand": [
                "makeTagDirectory"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.bam_file.basename.split('.')[0])"
                },
                {
                    "valueFrom": "$(\"default/\" + inputs.bam_file.basename)"
                }
            ],
            "doc": "Tool runs makeTagDirectory that basically parses through the alignment file and splits the tags into separate\nfiles based on the chromosomes.\n\nMultiple alignment files are not supported. Alignment file's format is restricted to be only BAM.\n\nOutput is placed in a folder with the name derived from the input BAM file's basename.\n\nSkipped arguments:\n\n  Rely on the default value:\n    -format           - format will be autodetected\n    -precision        - the default value is used\n\n  Not required general functionality:\n    -d\n    -single\n    -force5th\n    -t\n    -flip\n    -tbp\n\n  Not required GC-bias options:\n    -genome\n    -checkGC\n    -normGC\n    -normFixedOligo\n    -minNormRatio\n    -maxNormRatio\n    -iterNorm\n    -filterReads\n\n  Not required HiC options:\n    -removePEbg\n    -restrictionSite\n    -removeSpikes\n    -bowtiePE\n    -directional\n",
            "id": "#homer-make-tag-directory.cwl",
            "http://schema.org/mainEntity": {
                "$import": "#homer-metadata.yaml"
            },
            "http://schema.org/name": "homer-make-tag-directory",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/homer-make-tag-directory.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n  makeTagDirectory <directory> <alignment file 1> [file 2] ... [options]\n\n      Creates a platform-independent 'tag directory' for later analysis.\n      Currently BED, eland, bowtie, and sam files are accepted. The program will try to\n      automatically detect the alignment format if not specified.  Program will also\n      unzip *.gz, *.bz2, and *.zip files and convert *.bam to sam files on the fly\n      Existing tag directories can be added or combined to make a new one using -d/-t\n      If more than one format is needed and the program cannot auto-detect it properly,\n      make separate tag directories by running the program separately, then combine them.\n      To perform QC/manipulations on an existing tag directory, add \"-update\"\n\n      Options:\n          -fragLength <# | given | pe> (Set estimated fragment length or use PE length - given: use read lengths)\n              By default treats the sample as a single read ChIP-Seq experiment\n          -format <X> where X can be: (with column specifications underneath)\n              bed - BED format files:\n                  (1:chr,2:start,3:end,4:+/- or read name,5:# tags,6:+/-)\n                  -force5th (5th column of BED file contains # of reads mapping to position)\n              sam - SAM formatted files (use samTools to covert BAMs into SAM if you have BAM)\n                  -unique (keep if there is a single best alignment based on mapq)\n                      -mapq <#> (Minimum mapq for -unique, default: 10, set negative to use AS:i:/XS:i:)\n                  -keepOne (keep one of the best alignments even if others exist)\n                  -keepAll (include all alignments in SAM file)\n                  -mis (Maximum allowed mismatches, default: no limit, uses MD:Z: tag)\n                  -sspe (strand specific, paired-end reads[flips strand of 2nd read to match])\n                  -read1/-read2 (only analyze 1st or 2nd read for PE sequencing)\n              bowtie - output from bowtie (run with --best -k 2 options)\n                  (1:read name,2:+/-,3:chr,4:position,5:seq,6:quality,7:NA,8:misInfo)\n              eland_result - output from basic eland\n                  (1:read name,2:seq,3:code,4:#zeroMM,5:#oneMM,6:#twoMM,7:chr,\n                              8:position,9:F/R,10-:mismatches\n              eland_export - output from illumina pipeline (22 columns total)\n                  (1-5:read name info,9:sequence,10:quality,11:chr,13:position,14:strand)\n              eland_extended - output from illumina pipeline (4 columns total)\n                  (1:read name,2:sequence,3:match stats,4:positions[,])\n              mCpGbed - encode style mCpG reporting in extended BED format, no auto-detect\n                  (1:chr,2:start,3:end,4:name,5:,6:+/-,7:,8:,9:,10:#C,11:#mC)\n              allC - Lister style output files detailing the read information about all cytosines\n                  (1:chr,2:pos,3:strand,4:context,#mC,#totalC,#unmC\n              bismark - Bismark style output files detailing the read information about all cytosines\n                  (1:chr,2:pos,3:strand,4:#mC,5:#unmC,6:context,7:triseq\n                  -minCounts <#> (minimum number of reads to report mC/C ratios, default: 10)\n                  -mCcontext <CG|CHG|CHH|all> (only use C's in this context, default: CG)\n              HiCsummary - minimal paired-end read mapping information\n                  (1:readname,2:chr1,3:5'pos1,4:strand1,5:chr2,6:5'pos2,7:strand2)\n          -flip (flip strand of each read, i.e. might want to use with some RNA-seq)\n          -totalReads <#|all|default> (set the effective total number of reads - all includes multimappers)\n          -force5th (5th column of BED file contains # of reads mapping to position)\n          -d <tag directory> [tag directory 2] ... (add Tag directory to new tag directory)\n          -t <tag file> [tag file 2] ... (add tag file i.e. *.tags.tsv to new tag directory)\n          -single (Create a single tags.tsv file for all \"chromosomes\" - i.e. if >100 chromosomes)\n          -update (Use current tag directory for QC/processing, do not parse new alignment files)\n          -tbp <#> (Maximum tags per bp, default: no maximum)\n          -precision <1|2|3> (number of decimal places to use for tag totals, default: 1)\n          -minlen <#> and -maxlen <#> (Filter reads with lengths outside this range)\n\n          GC-bias options:\n          -genome <genome version> (To see available genomes, use \"-genome list\")\n              -or- (for custom genomes):\n          -genome <path-to-FASTA file or directory of FASTA files>\n\n          -checkGC (check Sequence bias, requires \"-genome\")\n              -freqStart <#> (offset to start calculating frequency, default: -50)\n              -freqEnd <#> (distance past fragment length to calculate frequency, default: +50)\n              -oligoStart <#> (oligo bias start)\n              -oligoEnd <#> (oligo bias end)\n          -normGC <target GC profile file> (i.e. tagGCcontent.txt file from control experiment)\n              Use \"-normGC default\" to match the genomic GC distribution\n          -normFixedOligo <oligoFreqFile> (normalize 5' end bias, \"-normFixedOligo default\" ok)\n          -minNormRatio <#> (Minimum deflation ratio of tag counts, default: 0.25)\n          -maxNormRatio <#> (Maximum inflation ratio of tag counts, default: 2.0)\n          -iterNorm <#> (Sets -max/minNormRatio to 1 and 0, iteratively normalizes such that the\n              resulting distrubtion is no more than #% different than target, i.e. 0.1,default: off)\n          -filterReads <seq> <offset> <keep|remove> (filter reads based on oligo sequence in the genome)\n\n      HiC options\n          -removePEbg (remove paired end tags within 1.5x fragment length on same chr)\n              -PEbgLength <#> (remove PE  reads facing on another within this distance, default: 1.5x fragLen)\n          -restrictionSite <seq> (i.e. AAGCTT for HindIII, assign data < 1.5x fragment length to sites)\n              Must specify genome sequence directory too. (-rsmis <#> to specify mismatches, def: 0)\n              -both, -one, -onlyOne, -none (Keeps reads near restriction sites, default: keep all)\n              -removeSelfLigation (removes reads linking same restriction fragment)\n              -removeRestrictionEnds (removes reads starting on a restriction fragment)\n              -assignMidPoint (will place reads in the middle of HindIII fragments)\n              -restrictionSiteLength <#> (maximum distance from restriction site, default: 1.5x fragLen)\n          -removeSpikes <size bp> <#> (remove tags from regions with > than # times\n              the average tags per size bp, suggest \"-removeSpikes 10000 8\")\n          -bowtiePE (PE alignments in bowtie alignment, assumes last character of read name is 0 or 1)\n              (don't need this for sam/bam files)\n          -directional (matrix is not symetric, i.e. grid-seq, 1st/2nd read mean something)"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "label": "BAM files",
                    "format": "http://edamontology.org/format_2572",
                    "doc": "Array of input BAM files",
                    "id": "#main/bam_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "label": "Export heatmap instead of a histogram",
                    "doc": "Export heatmap instead of a histogram",
                    "id": "#main/export_heatmap"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "label": "Fragment sizes",
                    "doc": "Array of fragment sizes",
                    "id": "#main/fragment_size"
                },
                {
                    "type": "File",
                    "label": "Genelist file",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "Genelist file",
                    "id": "#main/genelist_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 50,
                    "label": "Histogram/Heatmap bin size, bp",
                    "doc": "Histogram/Heatmap bin size, bp",
                    "id": "#main/hist_bin_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20000,
                    "label": "Histogram/Heatmap width, bp",
                    "doc": "Histogram/Heatmap width, bp",
                    "id": "#main/hist_width"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "id": "#main/threads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "label": "Total reads numbers",
                    "doc": "Array of total reads number for downstream normalization",
                    "id": "#main/total_reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/make_tss_heatmap/histogram_file",
                    "id": "#main/heatmap_file_raw"
                }
            ],
            "steps": [
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/genelist_file",
                            "id": "#main/center_genelist_on_tss/input_file"
                        },
                        {
                            "default": "cat \"$0\" | grep -v \"refseq_id\" | awk '{tss=$4; if ($6 == \"-\") tss=$5; print $2\"\\t\"$3\"\\t\"tss\"\\t\"tss\"\\t\"$6}' > `basename $0`",
                            "id": "#main/center_genelist_on_tss/script"
                        }
                    ],
                    "out": [
                        "#main/center_genelist_on_tss/output_file"
                    ],
                    "id": "#main/center_genelist_on_tss"
                },
                {
                    "run": "#heatmap-prepare.cwl",
                    "in": [
                        {
                            "source": "#main/bam_file",
                            "id": "#main/make_tag_folders/bam_file"
                        },
                        {
                            "source": "#main/fragment_size",
                            "id": "#main/make_tag_folders/fragment_size"
                        },
                        {
                            "source": "#main/total_reads",
                            "id": "#main/make_tag_folders/total_reads"
                        }
                    ],
                    "out": [
                        "#main/make_tag_folders/tag_folder"
                    ],
                    "id": "#main/make_tag_folders"
                },
                {
                    "run": "#homer-annotate-peaks-hist.cwl",
                    "in": [
                        {
                            "source": "#main/export_heatmap",
                            "id": "#main/make_tss_heatmap/export_heatmap"
                        },
                        {
                            "source": "#main/hist_bin_size",
                            "id": "#main/make_tss_heatmap/hist_bin_size"
                        },
                        {
                            "source": "#main/hist_width",
                            "id": "#main/make_tss_heatmap/hist_width"
                        },
                        {
                            "default": "default.tsv",
                            "id": "#main/make_tss_heatmap/histogram_filename"
                        },
                        {
                            "source": "#main/center_genelist_on_tss/output_file",
                            "id": "#main/make_tss_heatmap/peak_file"
                        },
                        {
                            "source": "#main/make_tag_folders/tag_folder",
                            "id": "#main/make_tss_heatmap/tag_folders"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/make_tss_heatmap/threads"
                        }
                    ],
                    "out": [
                        "#main/make_tss_heatmap/histogram_file"
                    ],
                    "id": "#main/make_tss_heatmap"
                }
            ],
            "doc": "Generates ATDP heatmap centered on TSS from an array of input BAM files and genelist TSV file.\nReturns array of heatmap JSON files with the names that have the same basenames as input BAM files,\nbut with .json extension\n",
            "id": "#main",
            "http://schema.org/name": "heatmap",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/workflows/heatmap.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Generates ATDP heatmap centered on TSS from an array of input BAM files and genelist TSV file.\nReturns array of heatmap JSON files with the names that have the same basenames as input BAM files,\nbut with .json extension"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
